.. tiote documentation master file, created by
   sphinx-quickstart on Sun Apr 29 12:18:32 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

=====
tiote
=====

Tiote enables django websites to administer PostgreSQL and MySQL databases. It provides a clean and intuitive interface to your database(s) with which you can use Database level functions.

Table of Contents
-----------------

.. toctree::
   :maxdepth: 2

   Installation <installation>
   Customisation <customisation>
   Project Overview <overview>
   Frequestly Asked Questions <faq>
   ChangeLog <changelog>


Links
-----
* `Code <http://github.com/dumb906/tiote>`_

* `Bug Tracker <http://github.com/dumb906/tiote/issues>`_

* `Mailing List <https://groups.google.com/group/tiote>`_